@@ -1,17 +1,41 @@
 // SPDX-License-Identifier: (Apache-2.0 OR MIT)
 
 macro_rules! is_type {
-    ($obj_ptr:ident, $type_ptr:ident) => {
+    ($obj_ptr:expr, $type_ptr:expr) => {
         unsafe { $obj_ptr == $type_ptr }
     };
 }
 
+macro_rules! ob_type {
+    ($obj:expr) => {
+        unsafe { (*$obj).ob_type }
+    };
+}
+
+macro_rules! err {
+    ($msg:expr) => {
+        return Err(serde::ser::Error::custom($msg));
+    };
+}
+
 macro_rules! unlikely {
     ($exp:expr) => {
         unsafe { std::intrinsics::unlikely($exp) }
     };
 }
 
+macro_rules! likely {
+    ($exp:expr) => {
+        unsafe { std::intrinsics::likely($exp) }
+    };
+}
+
+macro_rules! nonnull {
+    ($exp:expr) => {
+        unsafe { std::ptr::NonNull::new_unchecked($exp) }
+    };
+}
+
 macro_rules! str_from_slice {
     ($ptr:expr, $size:expr) => {
         unsafe { std::str::from_utf8_unchecked(std::slice::from_raw_parts($ptr, $size as usize)) }
